Crate rullst_orm

Crate rullst_orm 

Re-exports

pub use error::RullstError as Error;
pub use admin::dashboard_html;
pub use collection::RullstCollection;
pub use database::RullstDatabase;
pub use policy::Policy;
pub use privacy::ComplianceModel;
pub use privacy::PrivacyReport;
pub use privacy::SecretString;
pub use resource::ApiResource;
pub use resource::JsonResource;
pub use resource::ResourceCollection;
pub use scout::SearchEngine;
pub use scout::get_search_engine;
pub use scout::set_search_engine;
pub use tenant::get_tenant_id;
pub use tenant::with_tenant;
pub use types::Json;
pub use schema::JoinClause;
pub use schema::SubqueryBuilder;

Modules

admin
audit
collection
database
db
error
policy
privacy
raw
resource
schema
scout
tenant
types

Macros

dispatch_executor
execute_query

Structs

Orm
Orm configuration structure
PaginationResult
Represents a paginated result set

Enums

RullstValue
Enum dinâmico para encapsular qualquer tipo que possa ser associado ao banco de dados pelo Macro

Statics

CURRENT_TX

Traits

FromRow
A record that can be built from a row returned by the database.
RullstModel
The core trait that all Orm models will implement via #[derive(Orm)]
Seeder
A database seeder trait for populating tables

Functions

prevent_lazy_loading
Prevents relationships from being lazily loaded when accessed without being eager loaded. When enabled, attempting to lazily load a relation will throw a panic in development.

Type Aliases

RullstPool
RullstPoolOptions

Attribute Macros

async_trait
test

Derive Macros

Enum
FromRow
Orm
PersonalData