pub struct Orm;Expand description
Orm configuration structure
Implementations
Sourceimpl Orm
impl Orm
Sourcepub async fn init(database_url: &str) -> Result<(), Error>
pub async fn init(database_url: &str) -> Result<(), Error>
Initialize the global database connection pool using an agnostic URI
Sourcepub async fn init_with_replicas(
primary_url: &str,
replica_urls: Vec<&str>,
) -> Result<(), Error>
pub async fn init_with_replicas( primary_url: &str, replica_urls: Vec<&str>, ) -> Result<(), Error>
Initialize the global database connection pool and its read replicas
Sourcepub fn pool() -> &'static RullstPool
pub fn pool() -> &'static RullstPool
Retrieve the global database connection pool (strictly for writes)
Sourcepub fn read_pool() -> &'static RullstPool
pub fn read_pool() -> &'static RullstPool
Retrieve the connection pool for read operations. Performs a round-robin load balancing over replicas if configured.
pub async fn begin_transaction() -> Result<Transaction<'static>, Error>
Sourcepub async fn seed(seeders: Vec<Box<dyn Seeder>>) -> Result<(), Error>
pub async fn seed(seeders: Vec<Box<dyn Seeder>>) -> Result<(), Error>
Run an array of seeders sequentially
Sourcepub fn enable_query_log()
pub fn enable_query_log()
Enable query logging to print all queries to the terminal
Sourcepub fn disable_query_log()
pub fn disable_query_log()
Disable query logging