pub struct Json<T>(pub T);Expand description
A wrapper for JSON columns in the database. This type allows users to easily cast a column to a struct that implements Serialize and Deserialize.
Tuple Fields
0: TTrait Implementations
Sourceimpl<'r, T: DeserializeOwned> Decode<'r, Any> for Json<T>
Available on neither crate feature strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.
impl<'r, T: DeserializeOwned> Decode<'r, Any> for Json<T>
Available on neither crate feature
strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.Sourceimpl<'de, T> Deserialize<'de> for Json<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Json<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'q, T: Serialize> Encode<'q, Any> for Json<T>
Available on neither crate feature strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.
impl<'q, T: Serialize> Encode<'q, Any> for Json<T>
Available on neither crate feature
strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.Sourcefn encode_by_ref(
&self,
buf: &mut <Any as Database>::ArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>
fn encode_by_ref( &self, buf: &mut <Any as Database>::ArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Send + Sync>>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Send + Sync>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
Sourceimpl<T> Type<Any> for Json<T>
Available on neither crate feature strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.
impl<T> Type<Any> for Json<T>
Available on neither crate feature
strict-mysql nor crate feature strict-postgres nor crate feature strict-sqlite.impl<T: Eq> Eq for Json<T>
impl<T> StructuralPartialEq for Json<T>